;| InsertAcadFile
-------------------------------------------------------------------------------

Fgt alle Arten von AutoCAD-Zeichnungsdateien als Block
in die aktuelle Zeichnung ein.
Dabei kann die Datei so eingefgt werden,
dass lediglich Layer, Blcke, Stile, etc. aus dieser bernommen werden.
(Entspricht dem Abbrechen bei einer Blockeinfgung)

Dateien mit den folgenden Endungen knnen gewhlt werden:
DWG, DXF, DWT, DWS, BAK, SV$


-------------------------------------------------------------------------------
Copyright (C) 2006 Markus Hoffmann
www.CADmaro.de
-------------------------------------------------------------------------------
FREEWARE:
Dieser Quellcode darf unbegrenzt und fr jeden Zweck verwendet werden sofern
keine Gebhr erhoben wird. Der Quellcode darf weiterhin nach eigenen
Bedrfnissen anpasst, verbessert, kopiert und weitergegeben werden. Der
Urheberrechtshinweis darf nicht entfernt werden.
-------------------------------------------------------------------------------
|;
(defun c:InsertAcadFile (/ wscript anyfilename jaodernein dwgfilename)
  (mx:Init)
  (setq wscript (vlax-create-object "WScript.shell"))
  (if
    (setq anyfilename
           (getfiled "Insert Any Acad File"
                     (strcat
                       (getvar "DWGPREFIX")
                       "\\"
                     )
                     "dwg;dxf;dwt;dws;bak;sv$"
                     4
           )
    )
     (progn
       (setq jaodernein
              (vlax-invoke-method
                wscript
                'Popup
                "Blockeinfgung abbrechen um nur Layer, Blcke, Stile, etc. einzufgen?"
                0
                "Wichtige Frage"
                4
               )
       )
       (cond
         ((mx:wcmatchlist
            (list (substr (vl-filename-extension anyfilename) 2))
            "dwg,dxf,dws"
          )
          (mx:Insert anyfilename
                     (if (= 7 jaodernein)
                       '((0 0 0) 1 1 0)
                     )
          )
         )
         ((mx:wcmatchlist
            (list (substr (vl-filename-extension anyfilename) 2))
            "dwt,sv$,bak"
          )
          (vl-file-copy
            anyfilename
            (setq dwgfilename (vl-filename-mktemp nil nil ".dwg"))
          )
          (mx:Insert dwgfilename
                     (if (= 7 jaodernein)
                       '((0 0 0) 1 1 0)
                     )
          )
          (vl-file-delete dwgfilename)
         )
         ('T
          (alert
            (strcat
              "Konnte Datei "
              anyfilename
              " nicht einfgen."
            )
          )
         )
       )
     )
  )
  (vlax-release-object wscript)
  (mx:Reset)
  (princ)
)

 ;| mx:Insert
fgt bergebene Datei ein
Wenn Einfgeparameter mitgegeben werden, wird die Datei wirklich eingefgt,
Wenn nicht, wird beim Einfgen abgebrochen, d.h. Layer, Blcke, Stile sind vorhanden, aber die Grafik fehlt.


Beispiele:

Einfgen in 0,0,0 - Skalierung 1 - Drehwinkel 0:
(mx:Insert "d:\\temp\\x.dwg" '((0 0 0) 1 1 0))

Einfgen mit Abbruch:
(mx:Insert "d:\\temp\\x.dwg" nil)
|;
(defun mx:Insert (fname params /)
  (command "_-insert"
           fname
           (if params
             (mapcar 'command params)
             (command)
           )
  )
  (if params
    (princ
      (strcat "\nDie Datei wurde in "
              (vl-princ-to-string (car params))
              " eingefgt."
      )
    )
    (princ
      "\nDie Layer, Blcke, Stile, etc. der Datei wurden eingefgt."
    )
  )
)

 ;| mx:wcmatchlist
vergleicht eine Liste von Strings mit verschiedenen Patterns
Parameter:	Liste mit Strings
		Testpatterns
Rckgabe:	Treffer oder nil
Bsp.:		(mx:wcmatchlist '("dwg" "dxx" "sv$") "DWG,DWT,DXF")
|;
(defun mx:wcmatchlist (listofstrings patterns)
  (vl-remove-if-not
    '(lambda (x)
       (wcmatch (strcase x) (strcase patterns))
     )
    listofstrings
  )
)

;| mx:Init

Initialisierung
|;
(defun mx:Init ()
  (vl-load-com)
  (setq objAcDoc
         (vlax-get-property
           (vlax-get-acad-object)
           'ActiveDocument
         )
  )
  (setq intECHO (getvar "CMDECHO"))
  (setvar "CMDECHO" 0)
  (setq errorMX *error*
        *error* mx:Error
  )
  (vlax-invoke-method objAcDoc 'EndUndomark)
  (vlax-invoke-method objAcDoc 'StartUndomark)
)

 ;| mx:Reset

Zurcksetzen
|;
(defun mx:Reset ()
  (setvar "CMDECHO" intECHO)
  (vlax-invoke-method objAcDoc 'EndUndomark)
  (vlax-release-object objAcDoc)
  (setq *error* errorMX)
  (mapcar
    '(lambda (arg)
       (set
         arg
         'nil
       )
     )
    (list 'errorMX 'intECHO 'objAcDoc)
  )
)

 ;| mx:Error

Errorfunktion
|;
(defun mx:Error (s)
  (print (strcat "Fehler " s))
  (command)
  (command "_.undo" "_back")
  (mx:Reset)
  (princ)
)

;;; Kurzbefehl definieren
(defun c:IAF ()
  (c:InsertAcadFile)
)

(princ
  "\nInsertAcadFile.lsp wurde geladen. Zum Starten bitte \"IAF\" oder \"InsertAcadFile\" eingeben."
)
(princ)